/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.network

import com.kakao.sdk.partner.friend.Constants
import com.kakao.sdk.partner.friend.model.PickerFriendFilter
import com.kakao.sdk.partner.friend.model.PickerFriendOrder
import com.kakao.sdk.partner.friend.model.PickerFriendType
import com.kakao.sdk.partner.friend.network.model.PickerChatMembers
import com.kakao.sdk.partner.friend.network.model.PickerChats
import com.kakao.sdk.partner.friend.network.model.PickerFriend
import com.kakao.sdk.partner.friend.network.model.PickerUsers
import retrofit2.Call
import retrofit2.http.GET
import retrofit2.http.Query

/**
 * @suppress
 */
internal interface FriendApi {

    @GET(Constants.V1_FRIENDS_PATH)
    fun friends(
        @Query(Constants.FRIEND_TYPE) friendType: PickerFriendType? = null,
        @Query(Constants.FRIEND_FILTER) friendFilter: PickerFriendFilter? = null,
        @Query(Constants.FRIEND_ORDER) friendOrder: PickerFriendOrder? = null,
        @Query(Constants.LIMIT) limit: Int? = null,
        @Query(Constants.COUNTRY_CODES) countryCodes: String? = null
    ): Call<PickerUsers<PickerFriend>>

    @GET(Constants.V1_CHATS_PATH)
    fun chatList(
        @Query(Constants.FILTER) filter: String? = null,
     //   @Query(Constants.OFFSET) offset: Int? = null,
        @Query(Constants.LIMIT) limit: Int? = null
        //@Query(Constants.ORDER) order: Order? = null
    ): Call<PickerChats>

    @GET(Constants.V1_CHAT_MEMBERS_PATH)
    fun chatMembers(
        @Query(Constants.CHAT_ID) chatId: Long,
        @Query(Constants.FRIENDS_ONLY) friendsOnly: Boolean? = null,
        @Query(Constants.INCLUDE_PROFILE) includeProfile: Boolean? = null,
        @Query(Constants.TOKEN) token: Long? = null
    ): Call<PickerChatMembers>
}