/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package com.kakao.sdk.partner.friend.network.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import com.kakao.sdk.common.json.UnknownValue
import kotlinx.android.parcel.Parcelize

/**
 * /v1/api/talk/members API 의 응답.
 *
 * @property activeMembersCount 챗방 내 톡친구의 수. 500의 최대값을 가진다. Friend_only 옵션을 true 로 준 경우에만 내려옴.
 * @property activeFriendsCount 챗방 내 멤버의 수. 500의 최대값을 가진다. Friend_only 옵션을 true 로 준 경우에만 내려옴.
 * @property members 해당 챗방에 참여중인 멤버의 [ChatMember] 리스트. 멤버수가 500명을 초과할 경우 500명만 내려오게 된다.
 * @property type 해당 챗방의 타입
 * @property token 	요청에 대한 토큰(Token) 정보
 */
@Parcelize
data class PickerChatMembers(
    val activeMembersCount: Int?,
    val activeFriendsCount: Int?,
    val members: List<PickerChatMember>?,
    val type: Type,
    val token: Long?
) : Parcelable {
    enum class Type {
        @SerializedName("DirectChat")
        DIRECT_CHAT,
        @SerializedName("MultiChat")
        MULTI_CHAT,
        @UnknownValue
        UNKNOWN;
    }
}

/**
 * @property appRegistered 챗 멤버의 앱 가입 여부
 * @property id 사용자 ID. [appRegistered] 가 true 인 경우에만 내려온다.
 * @property nickname 카카오톡 닉네임
 * @property thumbnailImageUrl 친구의 썸네일 이미지
 * @property uuid 해당 앱에서 유일한 친구의 code. 가변적인 데이터.
 */
@Parcelize
data class PickerChatMember(
    val appRegistered: Boolean?,
    val id: Long?,
    val nickname: String?,
    @SerializedName("thumbnail_image") val thumbnailImageUrl: String?,
    val uuid: String,
    val msgBlocked: Boolean?
) : Parcelable